#include "MainComponent.h"

//==============================================================================
MainComponent::MainComponent()
{
    windowOpenGLContext.setTopLevelParentComponent(*this);
    
    addAndMakeVisible(buttonAddWidget);
    buttonAddWidget.onClick = [&]
    {
        widgets.push_back(std::make_unique<Widget>(windowOpenGLContext));
        addAndMakeVisible(*widgets.back());
        resized();
    };
    addAndMakeVisible(buttonRemoveWidget);
    buttonRemoveWidget.onClick = [&]
    {
        if (widgets.size() > 0)
        {
            widgets.erase(widgets.end() - 1);
            resized();
        }
    };
    
    setSize (600, 400);
}

MainComponent::~MainComponent()
{
    windowOpenGLContext.detachTopLevelParentComponent();
}

//==============================================================================
void MainComponent::paint (juce::Graphics& g)
{
    // (Our component is opaque, so we must completely fill the background with a solid colour)
    g.fillAll (getLookAndFeel().findColour (juce::ResizableWindow::backgroundColourId));
}

void MainComponent::resized()
{
    buttonAddWidget.setBounds(10, 10, 100, 25);
    buttonRemoveWidget.setBounds(120, 10, 100, 25);
    
    if (widgets.size() > 0)
    {
        auto r = getLocalBounds().withTop(buttonAddWidget.getBottom() + 10);
        auto widthPerWidget = r.getWidth() / 10;//(int)widgets.size();
        for (auto& widget : widgets)
            widget->setBounds(r.removeFromLeft(widthPerWidget).reduced(5, 0));
    }
}
