/*
  ==============================================================================

    GraphComponent.h
    Created: 20 Mar 2019 10:41:53pm
    Author:  Adam Wilson

  ==============================================================================
*/

#pragma once

#include <JuceHeader.h>
#include <array>
#include <juce_audio_basics/juce_audio_basics.h>
#include "Plot2D.h"

typedef juce::AudioBuffer<float> DataBuffer;

#ifndef M_PI
#define M_PI 3.14159265358979323846
#endif

/**
 */
class GraphComponent : public Plot2D
{
public:

    static constexpr int glBufferSize = 256;
    static constexpr int dataBufferSize = 256;

    GraphComponent(WindowOpenGLContext& glContext)
            : Plot2D(true, glContext),
              dataBuffer(1, dataBufferSize)
    {
        setBackgroundColour(juce::Colours::black, false);
        setLines(1, legend);

        setXValues(juce::Range<float>(0, glBufferSize), 1.f, LogScaling::none);
        setYRange(juce::Range<float>(-1.5, 1.5), LogScaling::none);

        setLineWidthIfPossibleForGPU(2.5);
    }

    ~GraphComponent() override
    {
    }

    void resized() override
    {
    }

    void renderNextBuffer(const DataBuffer& newData)
    {
        dataBuffer = newData;
    }

private:
    DataBuffer dataBuffer;
    juce::StringArray legend;

    // Plot2D Member functions
    void beginFrame() override
    {
    }

    const float* getBufferForLine(int lineIndex) override
    {
        return dataBuffer.getReadPointer(lineIndex);
    }

    void endFrame() override
    {
    }
};

